@@ -199,7 +199,7 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
         cv2.waitKey(1)
         
     
-    def captureTestDimension(self)
+    def captureTestDimension(self):
         cv2.destroyAllWindows()
         cv2.waitKey(1)
         cv2.waitKey(1)
@@ -219,7 +219,7 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
         cv2.waitKey(40)
         self.camera.getImage(name = 'RadiometricTest/'+ 'testImage1', calibration=True)
         
-        pattern = np.zeros((DISPLAY_HEIGHT,DISPLAY_WIDTH))
+        pattern = np.ones((DISPLAY_HEIGHT,DISPLAY_WIDTH)) * 255
         cv2.imshow(window_name, pattern.astype(np.uint8))
         cv2.waitKey(40)
         self.camera.getImage(name = 'RadiometricTest/'+ 'testImage2', calibration=True)
